@@ -5,12 +5,11 @@ reV Base Configuration Framework
 import json
 import logging
 import os
-from warnings import warn
 
 from rex.utilities import safe_json_load
+from rex.utilities.utilities import get_class_properties
 
-from reV.utilities.exceptions import ConfigError, reVDeprecationWarning
-
+from reV.utilities.exceptions import ConfigError
 
 logger = logging.getLogger(__name__)
 REVDIR = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
@@ -19,14 +18,17 @@ TESTDATADIR = os.path.join(os.path.dirname(REVDIR), 'tests', 'data')
 
 class BaseConfig(dict):
     """Base class for configuration frameworks."""
+    REQUIREMENTS = ()
 
-    def __init__(self, config):
+    def __init__(self, config, check_keys=True):
         """
         Parameters
         ----------
         config : str | dict
             File path to config json (str), serialized json object (str),
             or dictionary with pre-extracted config.
+        check_keys : bool, optional
+            Flag to check config keys against Class properties, by default True
         """
 
         # str_rep is a mapping of config strings to replace with real values
@@ -39,16 +41,14 @@ class BaseConfig(dict):
         self._name = None
         self._parse_config(config)
 
-        self._base_preflight()
+        self._preflight()
 
-    def _base_preflight(self):
-        """Run a base preflight check on the config."""
-        if 'project_control' in self:
-            w = ('Deprecation warning: config "project_control" block is no '
-                 'longer used. All project control keys are moved to the top '
-                 'config level.')
-            logger.warning(w)
-            warn(w, reVDeprecationWarning)
+        self._keys = self._get_properties()
+        if check_keys:
+            self._check_keys()
+
+    def __repr__(self):
+        return self.__class__.__name__
 
     @property
     def config_dir(self):
@@ -61,6 +61,122 @@ class BaseConfig(dict):
         """
         return self._config_dir
 
+    @property
+    def config_keys(self):
+        """
+        List of valid config keys
+
+        Returns
+        -------
+        list
+        """
+        return self._keys
+
+    @property
+    def log_level(self):
+        """Get user-specified "log_level" (DEBUG, INFO, WARNING, etc...).
+
+        Returns
+        -------
+        log_level : int
+            Python logging module level (integer format) corresponding to the
+            config-specified log level string.
+        """
+
+        if self._log_level is None:
+            levels = {'DEBUG': logging.DEBUG,
+                      'INFO': logging.INFO,
+                      'WARNING': logging.WARNING,
+                      'ERROR': logging.ERROR,
+                      'CRITICAL': logging.CRITICAL,
+                      }
+
+            x = str(self.get('log_level', 'INFO'))
+            self._log_level = levels[x.upper()]
+
+        return self._log_level
+
+    @property
+    def name(self):
+        """Get the project name from the "name" key.
+
+        Returns
+        -------
+        name : str
+            Config-specified project control name.
+        """
+
+        if self._name is None:
+            self._name = self.get('name', 'rev')
+        return self._name
+
+    def _preflight(self):
+        """Run a preflight check on the config."""
+        if 'project_control' in self:
+            msg = ('config "project_control" block is no '
+                   'longer used. All project control keys should be placed at '
+                   'the top config level.')
+            logger.error(msg)
+            raise ConfigError(msg)
+
+        missing = []
+        for req in self.REQUIREMENTS:
+            if req not in self:
+                missing.append(req)
+
+        if any(missing):
+            e = '{} missing the following keys: {}'.format(self, missing)
+            logger.error(e)
+            raise ConfigError(e)
+
+    @classmethod
+    def _get_properties(cls):
+        """
+        Get all class properties
+        Used to check against config keys
+
+        Returns
+        -------
+        properties : list
+            List of class properties, each of which should represent a valid
+            config key/entry
+        """
+        return get_class_properties(cls)
+
+    def _check_keys(self):
+        """
+        Check on config keys to ensure they match available
+        properties
+        """
+        for key, value in self.items():
+            if isinstance(value, str) and key not in self._keys:
+                msg = ('{} is not a valid config entry for {}! Must be one of:'
+                       '\n{}'.format(key, self, self._keys))
+                logger.error(msg)
+                raise ConfigError(msg)
+
+    def check_overwrite_keys(self, primary_key, *overwrite_keys):
+        """
+        Check for overwrite keys and raise a ConfigError if present
+
+        Parameters
+        ----------
+        primary_key : str
+            Primary key that overwrites overwrite_keys, used for error message
+        overwrite_keys : str
+            Key(s) to overwrite
+        """
+        overwrite = []
+        for key in overwrite_keys:
+            if key in self:
+                overwrite.append(key)
+
+        if overwrite:
+            msg = ('A value for "{}" was provided which overwrites: "{}"'
+                   .format(primary_key, ', '.join(overwrite)))
+            logger.error(msg)
+            raise ConfigError(msg)
+
     def _parse_config(self, config):
         """Parse a config input and set appropriate instance attributes.
 
@@ -175,41 +291,3 @@ class BaseConfig(dict):
             raise ConfigError('Unknown error getting configuration file: "{}"'
                               .format(fname))
         return config
-
-    @property
-    def log_level(self):
-        """Get user-specified "log_level" (DEBUG, INFO, WARNING, etc...).
-
-        Returns
-        -------
-        log_level : int
-            Python logging module level (integer format) corresponding to the
-            config-specified log level string.
-        """
-
-        if self._log_level is None:
-            levels = {'DEBUG': logging.DEBUG,
-                      'INFO': logging.INFO,
-                      'WARNING': logging.WARNING,
-                      'ERROR': logging.ERROR,
-                      'CRITICAL': logging.CRITICAL,
-                      }
-
-            x = str(self.get('log_level', 'INFO'))
-            self._log_level = levels[x.upper()]
-
-        return self._log_level
-
-    @property
-    def name(self):
-        """Get the project name from the "name" key.
-
-        Returns
-        -------
-        name : str
-            Config-specified project control name.
-        """
-
-        if self._name is None:
-            self._name = self.get('name', 'rev')
-        return self._name
