@@ -17,7 +17,7 @@ from reV.supply_curve.sc_aggregation import SupplyCurveAggregation
 from rex.utilities.execution import SLURM
 from rex.utilities.cli_dtypes import STR, INT, FLOAT, FLOATLIST, STRFLOAT
 from rex.utilities.loggers import init_mult
-from rex.utilities.utilities import dict_str_load
+from rex.utilities.utilities import dict_str_load, get_class_properties
 
 logger = logging.getLogger(__name__)
 
@@ -35,6 +35,14 @@ def main(ctx, name, verbose):
     ctx.obj['VERBOSE'] = verbose
 
 
+@main.command()
+def valid_config_keys():
+    """
+    Echo the valid SupplyCurveAggregation config keys
+    """
+    click.echo(', '.join(get_class_properties(SupplyCurveAggregationConfig)))
+
+
 @main.command()
 @click.option('--config_file', '-c', required=True,
               type=click.Path(exists=True),
@@ -131,8 +139,8 @@ def from_config(ctx, config_file, verbose):
         ctx.obj['VERBOSE'] = verbose
 
         ctx.invoke(slurm,
-                   alloc=config.execution_control.alloc,
-                   memory=config.execution_control.node_mem,
+                   alloc=config.execution_control.allocation,
+                   memory=config.execution_control.memory,
                    feature=config.execution_control.feature,
                    walltime=config.execution_control.walltime,
                    conda_env=config.execution_control.conda_env,
