@@ -15,7 +15,7 @@ from reV.supply_curve.supply_curve import SupplyCurve
 from rex.utilities.execution import SLURM
 from rex.utilities.cli_dtypes import STR, INT
 from rex.utilities.loggers import init_mult
-from rex.utilities.utilities import dict_str_load
+from rex.utilities.utilities import dict_str_load, get_class_properties
 
 logger = logging.getLogger(__name__)
 
@@ -33,6 +33,14 @@ def main(ctx, name, verbose):
     ctx.obj['VERBOSE'] = verbose
 
 
+@main.command()
+def valid_config_keys():
+    """
+    Echo the valid SupplyCurve config keys
+    """
+    click.echo(', '.join(get_class_properties(SupplyCurveConfig)))
+
+
 @main.command()
 @click.option('--config_file', '-c', required=True,
               type=click.Path(exists=True),
@@ -116,8 +124,8 @@ def from_config(ctx, config_file, verbose):
         ctx.obj['VERBOSE'] = verbose
 
         ctx.invoke(slurm,
-                   alloc=config.execution_control.alloc,
-                   memory=config.execution_control.node_mem,
+                   alloc=config.execution_control.allocation,
+                   memory=config.execution_control.memory,
                    walltime=config.execution_control.walltime,
                    feature=config.execution_control.feature,
                    conda_env=config.execution_control.conda_env,
@@ -228,6 +236,7 @@ def direct(ctx, sc_points, trans_table, fixed_charge_rate, sc_features,
         finput = [sc_points, trans_table]
         if sc_features is not None:
             finput.append(sc_features)
+
         if transmission_costs is not None:
             finput.append(transmission_costs)
 
